'use client'

import { useState } from 'react'
import { useSession } from 'next-auth/react'
import { loadStripe } from '@stripe/stripe-js'
import { Button } from '@/components/ui/button'
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from '@/components/ui/card'

const stripePromise = loadStripe(process.env.NEXT_PUBLIC_STRIPE_PUBLISHABLE_KEY!)

const TICKET_PRICE = 50 // Price in dollars

export default function TicketPurchase() {
  const { data: session } = useSession()
  const [isLoading, setIsLoading] = useState(false)

  const handlePurchase = async () => {
    setIsLoading(true)
    try {
      const response = await fetch('/api/create-checkout-session', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ price: TICKET_PRICE }),
      })

      const { sessionId } = await response.json()
      const stripe = await stripePromise
      const { error } = await stripe!.redirectToCheckout({ sessionId })

      if (error) {
        console.error('Stripe error:', error)
        alert('Payment failed. Please try again.')
      }
    } catch (error) {
      console.error('Purchase error:', error)
      alert('An error occurred. Please try again.')
    } finally {
      setIsLoading(false)
    }
  }

  if (!session) {
    return null
  }

  return (
    <Card className="w-[350px] mb-8">
      <CardHeader>
        <CardTitle>Event Ticket</CardTitle>
        <CardDescription>One-time entry pass</CardDescription>
      </CardHeader>
      <CardContent>
        <p className="text-2xl font-bold text-center">${TICKET_PRICE}</p>
      </CardContent>
      <CardFooter className="flex justify-center">
        <Button onClick={handlePurchase} disabled={isLoading}>
          {isLoading ? 'Processing...' : 'Purchase Ticket'}
        </Button>
      </CardFooter>
    </Card>
  )
}

